complete -c shiny-mirrors -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c shiny-mirrors -n "__fish_use_subcommand" -s V -l version -d 'Print version'
complete -c shiny-mirrors -n "__fish_use_subcommand" -f -a "refresh" -d 'Get the perfect mirrors for you'
complete -c shiny-mirrors -n "__fish_use_subcommand" -f -a "status" -d 'Show status of mirrors you are using'
complete -c shiny-mirrors -n "__fish_use_subcommand" -f -a "config" -d 'Settings manipulation and magic'
complete -c shiny-mirrors -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s l -l last-sync -d 'Maximum last sync duration (Hours, Int)' -r
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s p -l ipv -d 'Which IP version the mirror has to support' -r -f -a "{v4	'',v6	''}"
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s m -l max -d 'Maximum of mirrors to write to local mirror list' -r
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s t -l timeout -d 'Time before a benchmark of each mirror timeouts (Seconds, Float)' -r
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s f -l file-size -d 'Size of a file the speed measured is with' -r -f -a "{big	'',medium	'',small	''}"
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s M -l measure-method -d 'If to measure only transfer time or total time' -r -f -a "{total	'',transfer	''}"
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s L -l limit -d 'Rank only N most recently synced mirrors' -r
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s d -l dry-run -d 'Don\'t actually write the found mirrors to a local mirror list'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s u -l updated-only -d 'Find mirrors which are uptodate, ignore max last sync'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s i -l interactive -d 'Interactively select which mirrors you want to write to local mirror list'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from refresh" -s h -l help -d 'Print help'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from status" -s h -l help -d 'Print help'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -l protocol-value -r
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -l branch-value -r
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -l country-value -r
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -l continent-value -r
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -s s -l setup -d 'Set all settings options'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -s c -l country -d 'Set a list of countries to filter with'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -s b -l branch -d 'Set a branch to filter with'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -s C -l continent -d 'Set a continent to filter with'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -s p -l protocol -d 'Set a list of protocols to filter with'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -s h -l help -d 'Print help'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -f -a "show" -d 'Show the settings'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from show" -s h -l help -d 'Print help'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -f -a "show" -d 'Show the settings'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from config; and __fish_seen_subcommand_from help; and not __fish_seen_subcommand_from show; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from refresh; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from help" -f -a "refresh" -d 'Get the perfect mirrors for you'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from refresh; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from help" -f -a "status" -d 'Show status of mirrors you are using'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from refresh; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from help" -f -a "config" -d 'Settings manipulation and magic'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from refresh; and not __fish_seen_subcommand_from status; and not __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c shiny-mirrors -n "__fish_seen_subcommand_from help; and __fish_seen_subcommand_from config; and not __fish_seen_subcommand_from show" -f -a "show" -d 'Show the settings'
